==> grande-KXL-0.5.tar.gz: grande-KXL-0.5/src/opening.c <==
//====================================================
// Grande
// Copyright (C) 2002, kacchan
// E-M@il address   fc3srx@mwnet.or.jp
// Homepage address http://www2.mwnet.or.jp/~fc3srx7
//====================================================
#include "grande.h"
#include "extern.h"

#define CENTER(str) (UP_LEFT + (WIDTH - KXL_TextWidth((str))) / 2)
#define TO_MENU "push [z] key to menu"

// ȥ
Uint8 *title[]={
  " 000  0000   000  0   0 0000  00000",
  "0   0 0   0 0   0 00  0 0   0 0    ",
  "0   0 0   0 0   0 00  0 0   0 0    ",
  "0     0000  00000 0 0 0 0   0 0000 ",
  "0 000 0 0   0   0 0  00 0   0 0    ",
  "0   0 0  0  0   0 0  00 0   0 0    ",
  " 0000 0   0 0   0 0   0 0000  00000",
  ""
};
// ˥塼
char *menu_str[]={
  "Game Start",
  "Key Operation",
  "Ranking",
  "Exit",
  " ",
  " ",
  " ",
  " ",
  "move   - Arrow Up or Down",
  "select - z               ",
  ""
};
// ե
char *key_str[] = {
  "Key Operation", " ",
  "Move to Right      - Arrow Right",
  "Move to Left       - Arrow Left ",
  "Move to Up         - Arrow Up   ",
  "Move to Down       - Arrow Down ",
  "MainShot/Pause off - z          ",
  "SubShot            - Left Shift ",
  "ChargeShot         - x          ",
  "Pause on           - s          ",
  "Back to Title      - Eacape     ",
  ""
};
Uint8 menu = 0;
Sint8 sel = 0;

//========================================
// ץ˥
//========================================
Bool Opening(void)
{
  static Uint16 OldKey = KNone;
  Uint16 i, j;
  Uint8 buff[65];

  // ȥ
  KXL_Rect rect = {UP_TOP, UP_LEFT, WIDTH, HEIGHT};
  KXL_ClearFrame(rect);
  for (i = 0; title[i][0]; i ++)
    for (j = 0; j < 35; j ++)
      if (title[i][j] != ' ')
        KXL_PutImage(PixBomb1->data[Root->Cnt % 13].img,
                     UP_LEFT + 10 + 9 * j + 16 - i * 2,
                     UP_TOP + 8 + 9 * i);
  if (menu == 0) {
    // ˥塼
    for (i = 0; menu_str[i][0]; i ++) {
      if (i == sel)
        KXL_Font(NULL, 0xff, 0x00, 0x00);
      else
        KXL_Font(NULL, 0xff, 0xff, 0xff);
      KXL_PutText(CENTER(menu_str[i]), UP_TOP + 140 + i * 16, menu_str[i]);
    }
  } else if (menu == 1) {
    // ե
    for (i = 0; key_str[i][0]; i ++) {
      KXL_Font(NULL, 0xff, 0xff, i == 0 ? 0x00 : 0xff);
      KXL_PutText(CENTER(key_str[i]), UP_TOP + 120 + i * 16, key_str[i]);
    }
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    KXL_PutText(CENTER(TO_MENU), UP_BOTTOM - 20, TO_MENU);
  } else if (menu == 2) {
    // 󥭥
    KXL_Font(NULL, 0xff, 0xff, 0x00);
    KXL_PutText(CENTER("Ranking Top 5"), UP_TOP + 120, "Ranking Top 5");
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    sprintf(buff, "Top Score Stage Name     ");
    KXL_PutText(CENTER(buff), UP_TOP + 140, buff);
    KXL_Font(NULL, 0xff, 0xff, 0xff);
    for (i = 0; i < 5; i ++) {
      sprintf(buff, "   %2d  %06d  %02d %-8s    ",
              i + 1,
              Ranking[i].Score,
              Ranking[i].Stage + 1,
              Ranking[i].Name);
      KXL_PutText(CENTER(buff), UP_TOP + 160 + i * 20, buff);
    }
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    KXL_PutText(CENTER(TO_MENU), UP_BOTTOM - 20, TO_MENU);
  }
  // Ƚ
  if (OldKey != Root->Key) {
    if (OldKey == KNone && Root->Key) {
      if (menu == 0) {
        KXL_PlaySound(SE_POW, KXL_SOUND_PLAY);
        // ˥塼
        if (Root->Key & KUp) {
          if (-- sel < 0) sel = 3;
        } else if (Root->Key & KDown) {
          sel = (++ sel) % 4;
        }
        if (Root->Key & KShot){
          Root->Key = KNone;
          menu = sel;
          if (menu == 0) {
            // ॹ
            Root->MainFlag = MainStart;
            Root->Stage       = 0;
            Root->Life        = 2;
            Root->Score       = 0;
            Root->Cnt         = 0;
          } else if (menu == 3)
            // λ
            return True;
        }
      } if (Root->Key & KShot) {
        menu = 0;
        Root->Key = KNone;
      }
    }
    OldKey = Root->Key;
  }
  return False;
}

==> grande-KXL-0.6.tar.gz: grande-KXL-0.6/src/opening.c <==
//====================================================
// Grande
// Copyright (C) 2002-2003, kacchan
// E-M@il address   ml@kxl.hn.org
// Homepage address http://kxl.hn.org
//====================================================
#include "grande.h"
#include "extern.h"

#define CENTER(str) (UP_LEFT + (WIDTH - KXL_TextWidth((str))) / 2)
#define TO_MENU "push [MainShot] to title"

// ȥ
Uint8 *title[]={
  " 000  0000   000  0   0 0000  00000",
  "0   0 0   0 0   0 00  0 0   0 0    ",
  "0   0 0   0 0   0 00  0 0   0 0    ",
  "0     0000  00000 0 0 0 0   0 0000 ",
  "0 000 0 0   0   0 0  00 0   0 0    ",
  "0   0 0  0  0   0 0  00 0   0 0    ",
  " 0000 0   0 0   0 0   0 0000  00000",
  ""
};
// ˥塼
char *menu_str[]={
  "Game Start",
  "Key Operation",
  "Joystick config",
  "Ranking",
  "Exit",
  " ",
  " ",
  " ",
  "move   - Arrow Up or Down",
  "select - MainShot        ",
  ""
};
// ե
char *key_str[] = {
  "Key Operation", " ",
  "Move to Right      - Arrow Right",
  "Move to Left       - Arrow Left ",
  "Move to Up         - Arrow Up   ",
  "Move to Down       - Arrow Down ",
  "MainShot/Pause off - z          ",
  "SubShot            - Left Shift ",
  "ChargeShot         - x          ",
  "Pause on           - s          ",
  "Back to Title      - Eacape     ",
  ""
};
Uint8 menu = 0;
Sint8 sel = 0;

//========================================
// ץ˥
//========================================
Bool Opening(void)
{
  static Uint16 OldKey = KNone;
  Uint16 i, j;
  Uint8 buff[65];

  // ȥ
  KXL_Rect rect = {UP_TOP, UP_LEFT, WIDTH, HEIGHT};
  KXL_ClearFrame(rect);
  for (i = 0; title[i][0]; i ++)
    for (j = 0; j < 35; j ++)
      if (title[i][j] != ' ')
        KXL_PutImage(PixBomb1->data[Root->Cnt % 13].img,
                     UP_LEFT + 10 + 9 * j + 16 - i * 2,
                     UP_TOP + 8 + 9 * i);
  if (menu == 0) {
    // ˥塼
    for (i = 0; menu_str[i][0]; i ++) {
      if (i == sel)
        KXL_Font(NULL, 0xff, 0x00, 0x00);
      else
        KXL_Font(NULL, 0xff, 0xff, 0xff);
      KXL_PutText(CENTER(menu_str[i]), UP_TOP + 140 + i * 16, menu_str[i]);
    }
  } else if (menu == 1) {
    // ե
    for (i = 0; key_str[i][0]; i ++) {
      KXL_Font(NULL, 0xff, 0xff, i == 0 ? 0x00 : 0xff);
      KXL_PutText(CENTER(key_str[i]), UP_TOP + 120 + i * 16, key_str[i]);
    }
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    KXL_PutText(CENTER(TO_MENU), UP_BOTTOM - 20, TO_MENU);
  } else if (menu == 2) {
    Root->MainFlag = MainJoystick;
    sel = 0;
    return False;
  } else if (menu == 3) {
    // 󥭥
    KXL_Font(NULL, 0xff, 0xff, 0x00);
    KXL_PutText(CENTER("Ranking Top 5"), UP_TOP + 120, "Ranking Top 5");
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    sprintf(buff, "Top Score Stage Name     ");
    KXL_PutText(CENTER(buff), UP_TOP + 140, buff);
    KXL_Font(NULL, 0xff, 0xff, 0xff);
    for (i = 0; i < 5; i ++) {
      sprintf(buff, "   %2d  %06d  %02d %-8s    ",
              i + 1,
              Ranking[i].Score,
              Ranking[i].Stage + 1,
              Ranking[i].Name);
      KXL_PutText(CENTER(buff), UP_TOP + 160 + i * 20, buff);
    }
    KXL_Font(NULL, 0x00, 0xff, 0xff);
    KXL_PutText(CENTER(TO_MENU), UP_BOTTOM - 20, TO_MENU);
  }
  // Ƚ
  if (OldKey != Root->Key) {
    if (OldKey == KNone && Root->Key) {
      if (menu == 0) {
        KXL_PlaySound(SE_POW, KXL_SOUND_PLAY);
        // ˥塼
        if (Root->Key & KUp) {
          if (-- sel < 0) sel = 4;
        } else if (Root->Key & KDown) {
          sel = (++ sel) % 5;
        }
        if (Root->Key & KShot){
          Root->Key = KNone;
          menu = sel;
          if (menu == 0) {
            // ॹ
            Root->MainFlag = MainStart;
            Root->Stage       = 0;
            Root->Life        = 2;
            Root->Score       = 0;
            Root->Cnt         = 0;
          } else if (menu == 4)
            // λ
            return True;
        }
      } if (Root->Key & KShot) {
        menu = 0;
        Root->Key = KNone;
      }
    }
    OldKey = Root->Key;
  }
  return False;
}

//========================================
// 祤ƥåե
//========================================
void ConfigJoystick(void)
{
  static Uint16 OldKey = KNone;
  Uint16 i, j;
  Uint32 button;
  Uint8 menubuff[6][25];
  // ȥ
  KXL_Rect rect = {UP_TOP, UP_LEFT, WIDTH, HEIGHT};
  KXL_ClearFrame(rect);
  for (i = 0; title[i][0]; i ++)
    for (j = 0; j < 35; j ++)
      if (title[i][j] != ' ')
        KXL_PutImage(PixBomb1->data[Root->Cnt % 13].img,
                     UP_LEFT + 10 + 9 * j + 16 - i * 2,
                     UP_TOP + 8 + 9 * i);

  KXL_Font(NULL, 0xff, 0xff, 0x00);
  KXL_PutText(CENTER("Joystick configure"), UP_TOP + 120, "Joystick configure");
  for (i = 1, button = JoyMainShot; !(button & 1); i ++)
    button >>= 1;
  sprintf(menubuff[0], "MainShot/Pause on - [%2d]", i);
  for (i = 1, button = JoySubShot; !(button & 1); i ++)
    button >>= 1;
  sprintf(menubuff[1], "SubShot           - [%2d]", i);
  for (i = 1, button = JoyChargeShot; !(button & 1); i ++)
    button >>= 1;
  sprintf(menubuff[2], "ChargeShot        - [%2d]", i);
  for (i = 1, button = JoyPause; !(button & 1); i ++)
    button >>= 1;
  sprintf(menubuff[3], "Pause on          - [%2d]", i);
  for (i = 1, button = JoyExit; !(button & 1); i ++)
    button >>= 1;
  sprintf(menubuff[4], "Back to Title     - [%2d]", i);
  sprintf(menubuff[5], "Return");
  for (i = 0; i < 6; i ++) {
    if (i == sel)
      KXL_Font(NULL, 0xff, 0x00, 0x00);
    else
      KXL_Font(NULL, 0xff, 0xff, 0xff);
    KXL_PutText(CENTER(menubuff[i]), UP_TOP + 140 + i * 16, menubuff[i]);
  }

  if (JoyConfig.buttons) {
    if (sel == 0)
      JoyMainShot = JoyConfig.buttons;
    else if (sel == 1)
      JoySubShot = JoyConfig.buttons;
    else if (sel == 2)
      JoyChargeShot = JoyConfig.buttons;
    else if (sel == 3)
      JoyPause = JoyConfig.buttons;
    else if (sel == 4)
      JoyExit = JoyConfig.buttons;
  }
  // Ƚ
  if (OldKey != Root->Key) {
    if (OldKey == KNone && Root->Key) {
      // ˥塼
      if (Root->Key & KUp) {
	if (-- sel < 0) sel = 5;
      } else if (Root->Key & KDown) {
	sel = (++ sel) % 6;
      }
      if (Root->Key & KShot){
	Root->Key = KNone;
	if (sel == 5) {
	  Root->MainFlag = MainOpening;
	  sel = menu = 0;
	  return;
	}
      }
    }
    OldKey = Root->Key;
  }
  return;
}
